@@ -210,7 +210,11 @@ def getDType(row, typeCodes, strLength):
             raise Exception('Unknown PG type  %d'%curt)
         pgType =__pgTypeHash[curt]
         if curt in strTypes:
-            pgType = pgType %(max(strLength, len(curv)))
+            if curv is not None:
+                curmax = max(strLength, len(curv))
+            else:
+                curmax = strLength
+            pgType = pgType %(curmax,)
         if curt not in strTypes:
             try:
                 len(curv)
@@ -299,13 +303,13 @@ def get(query, params=None, db="wsdb", driver="psycopg2", user=None,
             try:
                 while(True):
                     tups = cur.fetchmany()
+                    desc = cur.description
 
                     if tups == []:
                         break
                     
                     qIn.put(tups)
                     if nrec == 0:
-                        desc = cur.description
                         typeCodes = [_tmp.type_code for _tmp in desc]
                         colNames = [_tmp.name for _tmp in cur.description]
                         dtype = getDType(tups[0], typeCodes, strLength)
